@@ -13,7 +13,7 @@ df2 <- getData(data=sdf, varnames=c("dsex", "t088301"),
                                         to=c("No"))))
 table(df2)
 
-# When readNAEP is called on a data file, it appends a default 
+# when readNAEP is called on a data file, it appends a default 
 # condition to the edsurvey.data.frame. You can see these conditions
 # by printing the sdf
 sdf
@@ -23,11 +23,20 @@ sdf
 df2 <- getData(data=sdf, varnames=c("dsex", "b017451"), defaultConditions = FALSE)
 table(df2)
 
-# Similarly, the default behavior of omitting certain levels specified
+# similarly, the default behavior of omitting certain levels specified
 # in the edsurvey.data.frame can be changed as follows:
 df2 <- getData(data=sdf, varnames=c("dsex", "b017451"), omittedLevels = FALSE)
 table(df2)
 
+# omittedLevels can also be edited with setAttributes()
+# here, the omitted level "Multiple" is removed from the list
+sdfIncludeMultiple <- setAttributes(sdf, "omittedLevels", c(NA, "Omitted"))
+# check that it was set
+getAttributes(sdfIncludeMultiple, "omittedLevels")
+# notice that omittedLevels is TRUE, removing NA and "Omitted" still
+dfIncludeMultiple <- getData(data=sdfIncludeMultiple, varnames=c("dsex", "b017451"))
+table(dfIncludeMultiple)
+
 # the variable "c052601" is from the school-level data file; merging is handled automatically.
 # returns a light.edsurvey.data.frame using addAttributes=TRUE argument
 gddat <- getData(data=sdf, 
@@ -36,3 +45,15 @@ gddat <- getData(data=sdf,
 class(gddat)
 # look at the first few lines
 head(gddat)
+
+# get a selection of variables, recode using ifelse, and reappend attributes
+# with rebindAttributes so that it can be used with EdSurvey analysis functions
+df0 <- getData(sdf, c("composite", "dsex", "b017451", "origwt"))
+df0$sex <- ifelse(df0$dsex=="Male", "boy", "girl")
+df0 <- rebindAttributes(df0, sdf)
+
+\dontrun{
+# getting all the data can use up all the memory and is generally a bad idea
+df0 <- getData(sdf, varnames=colnames(sdf),
+               omittedLevels=FALSE, defaultConditions=FALSE)
+} 
