@@ -4,6 +4,13 @@ sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package="NAEPprimer"
 # search both the student and school files by a character string
 searchSDF(string="book", data=sdf)
 
+# use the `|` (OR) operator to search several strings simultaneously
+searchSDF(string="book|home|value", data=sdf)
+
+# use a vector of strings to search for variables that contain multiple strings,
+# such as both "book" and "home"
+searchSDF(string=c("book","home"), data=sdf)
+
 # search only the student files by a character string
 searchSDF(string="algebra", data=sdf, fileFormat="student")
 
